@@ -1,10 +1,14 @@
-# coding: utf-8
-from __future__ import absolute_import, division, print_function
-
 import string
 
 from hypothesis.strategies import (
-    composite, integers, just, lists, one_of, sampled_from, text)
+    composite,
+    integers,
+    just,
+    lists,
+    one_of,
+    sampled_from,
+    text,
+)
 
 from parver import Version
 
@@ -13,38 +17,38 @@ num_str = num_int.map(str)
 
 
 def epoch():
-    epoch = num_str.map(lambda s: s + '!')
-    return one_of(just(''), epoch)
+    epoch = num_str.map(lambda s: s + "!")
+    return one_of(just(""), epoch)
 
 
 @composite
 def release(draw):
     return draw(
-        num_str
-        .map(lambda s: [s] + draw(lists(num_str.map(lambda s: '.' + s))))
-        .map(lambda l: ''.join(l))
+        num_str.map(lambda s: [s] + draw(lists(num_str.map(lambda s: "." + s)))).map(
+            lambda l: "".join(l)
+        )
     )
 
 
 def separator(strict=False, optional=False):
-    sep = ['.']
+    sep = ["."]
 
     if optional:
-        sep.append('')
+        sep.append("")
 
     if not strict:
-        sep.extend(['-', '_'])
+        sep.extend(["-", "_"])
 
     return sampled_from(sep)
 
 
 @composite
 def pre(draw, strict=False):
-    words = ['a', 'b', 'rc']
+    words = ["a", "b", "rc"]
     if not strict:
-        words.extend(['c', 'alpha', 'beta', 'pre', 'preview'])
+        words.extend(["c", "alpha", "beta", "pre", "preview"])
 
-    blank = just('')
+    blank = just("")
 
     sep1 = separator(strict=strict, optional=True)
     if strict:
@@ -61,24 +65,21 @@ def pre(draw, strict=False):
     if not strict:
         num_part = one_of(blank, num_part)
 
-    nonempty = (
-        sep1
-        .map(lambda s: s + draw(word) + draw(num_part))
-    )
+    nonempty = sep1.map(lambda s: s + draw(word) + draw(num_part))
 
     return draw(one_of(blank, nonempty))
 
 
 @composite
 def post(draw, strict=False):
-    words = ['post']
+    words = ["post"]
     if not strict:
-        words.extend(['r', 'rev'])
+        words.extend(["r", "rev"])
 
     sep1 = separator(strict=strict, optional=not strict)
     word = sampled_from(words)
 
-    blank = just('')
+    blank = just("")
 
     sep2 = separator(strict=strict, optional=True)
     if strict:
@@ -93,7 +94,7 @@ def post(draw, strict=False):
     if strict:
         return draw(post)
 
-    post_implicit = num_str.map(lambda s: '-' + s)
+    post_implicit = num_str.map(lambda s: "-" + s)
 
     return draw(one_of(blank, post_implicit, post))
 
@@ -102,19 +103,19 @@ def post(draw, strict=False):
 def dev(draw, strict=False):
     sep = separator(strict=strict, optional=not strict)
 
-    blank = just('')
+    blank = just("")
 
     num_part = num_str
     if not strict:
         num_part = one_of(blank, num_part)
 
-    return draw(one_of(blank, sep.map(lambda s: s + 'dev' + draw(num_part))))
+    return draw(one_of(blank, sep.map(lambda s: s + "dev" + draw(num_part))))
 
 
 @composite
 def local_segment(draw):
     alpha = (
-        draw(one_of(just(''), integers(0, 9).map(str)))
+        draw(one_of(just(""), integers(0, 9).map(str)))
         + draw(text(string.ascii_lowercase, min_size=1, max_size=1))
         + draw(text(string.ascii_lowercase + string.digits))
     )
@@ -124,36 +125,36 @@ def local_segment(draw):
 @composite
 def local(draw, strict=False):
     if strict:
-        sep = just('.')
+        sep = just(".")
     else:
-        sep = sampled_from('-_.')
+        sep = sampled_from("-_.")
 
     part = local_segment()
     sep_part = sep.map(lambda s: s + draw(local_segment()))
-    sep_parts = lists(sep_part).map(lambda l: ''.join(l))
+    sep_parts = lists(sep_part).map(lambda l: "".join(l))
 
-    return draw(one_of(just(''), part.map(lambda s: '+' + s + draw(sep_parts))))
+    return draw(one_of(just(""), part.map(lambda s: "+" + s + draw(sep_parts))))
 
 
-whitespace = sampled_from(['', '\t', '\n', '\r', '\f', '\v'])
+whitespace = sampled_from(["", "\t", "\n", "\r", "\f", "\v"])
 
 
 def vchar(strict=False):
     if strict:
-        return just('')
-    return sampled_from(['', 'v'])
+        return just("")
+    return sampled_from(["", "v"])
 
 
 @composite
 def version_string(draw, strict=False):
     return (
-        draw(vchar(strict=strict)) +
-        draw(epoch()) +
-        draw(release()) +
-        draw(pre(strict=strict)) +
-        draw(post(strict=strict)) +
-        draw(dev(strict=strict)) +
-        draw(local(strict=strict))
+        draw(vchar(strict=strict))
+        + draw(epoch())
+        + draw(release())
+        + draw(pre(strict=strict))
+        + draw(post(strict=strict))
+        + draw(dev(strict=strict))
+        + draw(local(strict=strict))
     )
 
 
