@@ -1,11 +1,9 @@
-# coding: utf-8
 """The tests in this file have been adapted from the excellent test suite in
 packaging.version. See https://github.com/pypa/packaging
 
 Copyright (c) Donald Stufft and individual contributors.
 https://github.com/pypa/packaging/blob/master/LICENSE
 """
-from __future__ import absolute_import, division, print_function
 
 import itertools
 import operator
@@ -18,21 +16,61 @@ from parver import ParseError, Version
 # This list must be in the correct sorting order
 VERSIONS = [
     # Implicit epoch of 0
-    "1.0.dev456", "1.0a1", "1.0a2.dev456", "1.0a12.dev456", "1.0a12",
-    "1.0b1.dev456", "1.0b2", "1.0b2.post345.dev456", "1.0b2.post345",
-    "1.0b2-346", "1.0c1.dev456", "1.0c1", "1.0rc2", "1.0c3", "1.0",
-    "1.0.post456.dev34", "1.0.post456", "1.1.dev1", "1.2+123abc",
-    "1.2+123abc456", "1.2+abc", "1.2+abc123", "1.2+abc123def", "1.2+1234.abc",
-    "1.2+123456", "1.2.r32+123456", "1.2.rev33+123456",
-
+    "1.0.dev456",
+    "1.0a1",
+    "1.0a2.dev456",
+    "1.0a12.dev456",
+    "1.0a12",
+    "1.0b1.dev456",
+    "1.0b2",
+    "1.0b2.post345.dev456",
+    "1.0b2.post345",
+    "1.0b2-346",
+    "1.0c1.dev456",
+    "1.0c1",
+    "1.0rc2",
+    "1.0c3",
+    "1.0",
+    "1.0.post456.dev34",
+    "1.0.post456",
+    "1.1.dev1",
+    "1.2+123abc",
+    "1.2+123abc456",
+    "1.2+abc",
+    "1.2+abc123",
+    "1.2+abc123def",
+    "1.2+1234.abc",
+    "1.2+123456",
+    "1.2.r32+123456",
+    "1.2.rev33+123456",
     # Explicit epoch of 1
-    "1!1.0.dev456", "1!1.0a1", "1!1.0a2.dev456", "1!1.0a12.dev456", "1!1.0a12",
-    "1!1.0b1.dev456", "1!1.0b2", "1!1.0b2.post345.dev456", "1!1.0b2.post345",
-    "1!1.0b2-346", "1!1.0c1.dev456", "1!1.0c1", "1!1.0rc2", "1!1.0c3", "1!1.0",
-    "1!1.0.post456.dev34", "1!1.0.post456", "1!1.1.dev1", "1!1.2+123abc",
-    "1!1.2+123abc456", "1!1.2+abc", "1!1.2+abc123", "1!1.2+abc123def",
-    "1!1.2+1234.abc", "1!1.2+123456", "1!1.2.r32+123456", "1!1.2.rev33+123456",
-
+    "1!1.0.dev456",
+    "1!1.0a1",
+    "1!1.0a2.dev456",
+    "1!1.0a12.dev456",
+    "1!1.0a12",
+    "1!1.0b1.dev456",
+    "1!1.0b2",
+    "1!1.0b2.post345.dev456",
+    "1!1.0b2.post345",
+    "1!1.0b2-346",
+    "1!1.0c1.dev456",
+    "1!1.0c1",
+    "1!1.0rc2",
+    "1!1.0c3",
+    "1!1.0",
+    "1!1.0.post456.dev34",
+    "1!1.0.post456",
+    "1!1.1.dev1",
+    "1!1.2+123abc",
+    "1!1.2+123abc456",
+    "1!1.2+abc",
+    "1!1.2+abc123",
+    "1!1.2+abc123def",
+    "1!1.2+1234.abc",
+    "1!1.2+123456",
+    "1!1.2.r32+123456",
+    "1!1.2.rev33+123456",
 ]
 
 # Don't want an exception here if VERSIONS cannot be parsed,
@@ -44,7 +82,6 @@ except ParseError:  # pragma: no cover
 
 
 class TestVersion:
-
     @pytest.mark.parametrize("version", VERSIONS)
     def test_valid_versions(self, version):
         assert str(Version.parse(version)) == version
@@ -54,14 +91,13 @@ class TestVersion:
         [
             # Non sensical versions should be invalid
             "french toast",
-
             # Versions with invalid local versions
             "1.0+a+",
             "1.0++",
             "1.0+_foobar",
             "1.0+foo&asd",
             "1.0+1+1",
-        ]
+        ],
     )
     def test_invalid_versions(self, version):
         with pytest.raises(ParseError):
@@ -84,7 +120,6 @@ class TestVersion:
             ("1.0.DEV1", "1.0.dev1"),
             ("1.0-DEV", "1.0.dev0"),
             ("1.0-DEV1", "1.0.dev1"),
-
             # Various alpha incarnations
             ("1.0a", "1.0a0"),
             ("1.0.a", "1.0a0"),
@@ -106,7 +141,6 @@ class TestVersion:
             ("1.0.ALPHA1", "1.0a1"),
             ("1.0-ALPHA", "1.0a0"),
             ("1.0-ALPHA1", "1.0a1"),
-
             # Various beta incarnations
             ("1.0b", "1.0b0"),
             ("1.0.b", "1.0b0"),
@@ -128,7 +162,6 @@ class TestVersion:
             ("1.0.BETA1", "1.0b1"),
             ("1.0-BETA", "1.0b0"),
             ("1.0-BETA1", "1.0b1"),
-
             # Various release candidate incarnations
             ("1.0c", "1.0rc0"),
             ("1.0.c", "1.0rc0"),
@@ -150,7 +183,6 @@ class TestVersion:
             ("1.0.RC1", "1.0rc1"),
             ("1.0-RC", "1.0rc0"),
             ("1.0-RC1", "1.0rc1"),
-
             # Various post release incarnations
             ("1.0post", "1.0.post0"),
             ("1.0.post", "1.0.post0"),
@@ -172,10 +204,8 @@ class TestVersion:
             ("1.0-5", "1.0.post5"),
             ("1.0-r5", "1.0.post5"),
             ("1.0-rev5", "1.0.post5"),
-
             # Local version case insensitivity
             ("1.0+AbC", "1.0+abc"),
-
             # Integer Normalization
             ("1.01", "1.1"),
             ("1.0a05", "1.0a5"),
@@ -186,7 +216,6 @@ class TestVersion:
             ("1.1.dev09000", "1.1.dev9000"),
             ("00!1.2", "1.2"),
             ("0100!0.0", "100!0.0"),
-
             # Various other normalizations
             ("v1.0", "1.0"),
             ("   v1.0\t\n", "1.0"),
@@ -251,7 +280,7 @@ class TestVersion:
     def test_version_str_repr(self, version, expected):
         v = Version.parse(version).normalize()
         assert str(v) == expected
-        assert (repr(v) == "<Version {0}>".format(repr(expected)))
+        assert repr(v) == f"<Version {repr(expected)}>"
 
     def test_version_rc_and_c_equals(self):
         assert Version.parse("1.0rc1") == Version.parse("1.0c1")
@@ -451,31 +480,31 @@ class TestVersion:
             ("1.0", None),
             ("1.0.dev0", None),
             ("1.0.dev6", None),
-            ("1.0a1", ('a', 1)),
-            ("1.0a1.post5", ('a', 1)),
-            ("1.0a1.post5.dev6", ('a', 1)),
-            ("1.0rc4", ('rc', 4)),
+            ("1.0a1", ("a", 1)),
+            ("1.0a1.post5", ("a", 1)),
+            ("1.0a1.post5.dev6", ("a", 1)),
+            ("1.0rc4", ("rc", 4)),
             ("1.0.post5", None),
             ("1!1.0", None),
             ("1!1.0.dev6", None),
-            ("1!1.0a1", ('a', 1)),
-            ("1!1.0a1.post5", ('a', 1)),
-            ("1!1.0a1.post5.dev6", ('a', 1)),
-            ("1!1.0rc4", ('rc', 4)),
+            ("1!1.0a1", ("a", 1)),
+            ("1!1.0a1.post5", ("a", 1)),
+            ("1!1.0a1.post5.dev6", ("a", 1)),
+            ("1!1.0rc4", ("rc", 4)),
             ("1!1.0.post5", None),
             ("1.0+deadbeef", None),
             ("1.0.dev6+deadbeef", None),
-            ("1.0a1+deadbeef", ('a', 1)),
-            ("1.0a1.post5+deadbeef", ('a', 1)),
-            ("1.0a1.post5.dev6+deadbeef", ('a', 1)),
-            ("1.0rc4+deadbeef", ('rc', 4)),
+            ("1.0a1+deadbeef", ("a", 1)),
+            ("1.0a1.post5+deadbeef", ("a", 1)),
+            ("1.0a1.post5.dev6+deadbeef", ("a", 1)),
+            ("1.0rc4+deadbeef", ("rc", 4)),
             ("1.0.post5+deadbeef", None),
             ("1!1.0+deadbeef", None),
             ("1!1.0.dev6+deadbeef", None),
-            ("1!1.0a1+deadbeef", ('a', 1)),
-            ("1!1.0a1.post5+deadbeef", ('a', 1)),
-            ("1!1.0a1.post5.dev6+deadbeef", ('a', 1)),
-            ("1!1.0rc4+deadbeef", ('rc', 4)),
+            ("1!1.0a1+deadbeef", ("a", 1)),
+            ("1!1.0a1.post5+deadbeef", ("a", 1)),
+            ("1!1.0a1.post5.dev6+deadbeef", ("a", 1)),
+            ("1!1.0rc4+deadbeef", ("rc", 4)),
             ("1!1.0.post5+deadbeef", None),
         ],
     )
@@ -635,7 +664,7 @@ class TestVersion:
             ("1.0", False),
             ("1.0+foo", False),
             ("1.0.post1.dev1", True),
-            ("1.0.post1", True)
+            ("1.0.post1", True),
         ],
     )
     def test_version_is_postrelease(self, version, expected):
@@ -649,34 +678,37 @@ class TestVersion:
             *
             # Verify that the less than (<) operator works correctly
             [
-                [(x, y, operator.lt) for y in PARSED_VERSIONS[i + 1:]]
+                [(x, y, operator.lt) for y in PARSED_VERSIONS[i + 1 :]]
                 for i, x in enumerate(PARSED_VERSIONS)
-            ] +
+            ]
+            +
             # Verify that the less than equal (<=) operator works correctly
             [
                 [(x, y, operator.le) for y in PARSED_VERSIONS[i:]]
                 for i, x in enumerate(PARSED_VERSIONS)
-            ] +
+            ]
+            +
             # Verify that the equal (==) operator works correctly
-            [
-                [(x, x, operator.eq) for x in PARSED_VERSIONS]
-            ] +
+            [[(x, x, operator.eq) for x in PARSED_VERSIONS]]
+            +
             # Verify that the not equal (!=) operator works correctly
             [
                 [(x, y, operator.ne) for j, y in enumerate(PARSED_VERSIONS) if i != j]
                 for i, x in enumerate(PARSED_VERSIONS)
-            ] +
+            ]
+            +
             # Verify that the greater than equal (>=) operator works correctly
             [
-                [(x, y, operator.ge) for y in PARSED_VERSIONS[:i + 1]]
+                [(x, y, operator.ge) for y in PARSED_VERSIONS[: i + 1]]
                 for i, x in enumerate(PARSED_VERSIONS)
-            ] +
+            ]
+            +
             # Verify that the greater than (>) operator works correctly
             [
                 [(x, y, operator.gt) for y in PARSED_VERSIONS[:i]]
                 for i, x in enumerate(PARSED_VERSIONS)
             ]
-        )
+        ),
     )
     def test_comparison_true(self, left, right, op):
         assert op(left, right)
@@ -689,42 +721,43 @@ class TestVersion:
             *
             # Verify that the less than (<) operator works correctly
             [
-                [(x, y, operator.lt) for y in PARSED_VERSIONS[:i + 1]]
+                [(x, y, operator.lt) for y in PARSED_VERSIONS[: i + 1]]
                 for i, x in enumerate(PARSED_VERSIONS)
-            ] +
+            ]
+            +
             # Verify that the less than equal (<=) operator works correctly
             [
                 [(x, y, operator.le) for y in PARSED_VERSIONS[:i]]
                 for i, x in enumerate(PARSED_VERSIONS)
-            ] +
+            ]
+            +
             # Verify that the equal (==) operator works correctly
             [
                 [(x, y, operator.eq) for j, y in enumerate(PARSED_VERSIONS) if i != j]
                 for i, x in enumerate(PARSED_VERSIONS)
-            ] +
+            ]
+            +
             # Verify that the not equal (!=) operator works correctly
-            [
-                [(x, x, operator.ne) for x in PARSED_VERSIONS]
-            ] +
+            [[(x, x, operator.ne) for x in PARSED_VERSIONS]]
+            +
             # Verify that the greater than equal (>=) operator works correctly
             [
-                [(x, y, operator.ge) for y in PARSED_VERSIONS[i + 1:]]
+                [(x, y, operator.ge) for y in PARSED_VERSIONS[i + 1 :]]
                 for i, x in enumerate(PARSED_VERSIONS)
-            ] +
+            ]
+            +
             # Verify that the greater than (>) operator works correctly
             [
                 [(x, y, operator.gt) for y in PARSED_VERSIONS[i:]]
                 for i, x in enumerate(PARSED_VERSIONS)
             ]
-        )
+        ),
     )
     def test_comparison_false(self, left, right, op):
         assert not op(left, right)
 
     @pytest.mark.parametrize(("op", "expected"), [("eq", False), ("ne", True)])
     def test_compare_other(self, op, expected):
-        other = pretend.stub(
-            **{"__{0}__".format(op): lambda other: NotImplemented}
-        )
+        other = pretend.stub(**{f"__{op}__": lambda other: NotImplemented})
 
         assert getattr(operator, op)(Version.parse("1"), other) is expected
